@@ -64,7 +64,7 @@ class ServiceWithSizing(BaseModel):
         return vals
 
 
-class RestServiceConfig(BaseModel):
+class RestServiceConfig(ServiceWithSizing):
     """Additional info for REST services"""
 
     max_replicas: int
